==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/BooleanHandler.h <==
// class gnu.java.beans.decoder.BooleanHandler

// class file dependencies
// @dep_class 670cc122e6cfc20a gnu_java_beans_decoder_AbstractElementHandler
// @dep_class 825486895891e6aa gnu_java_beans_decoder_BooleanHandler
// @dep_class b0ac10a3c7037665 gnu_java_beans_decoder_SimpleHandler
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_SimpleHandler

#include "gnu/java/beans/decoder/SimpleHandler.h"

#ifndef _JC_gnu_java_beans_decoder_BooleanHandler_H_
#define _JC_gnu_java_beans_decoder_BooleanHandler_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_BooleanHandler$sub_refs	_jc_gnu_java_beans_decoder_BooleanHandler$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_BooleanHandler$sub_nonrefs	_jc_gnu_java_beans_decoder_BooleanHandler$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_BooleanHandler$refs	_jc_gnu_java_beans_decoder_BooleanHandler$refs;
typedef struct _jc_gnu_java_beans_decoder_BooleanHandler$nonrefs	_jc_gnu_java_beans_decoder_BooleanHandler$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_BooleanHandler$object	_jc_gnu_java_beans_decoder_BooleanHandler$object;

typedef const struct _jc_gnu_java_beans_decoder_BooleanHandler$vmethods	_jc_gnu_java_beans_decoder_BooleanHandler$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_BooleanHandler$vtable	_jc_gnu_java_beans_decoder_BooleanHandler$vtable;
typedef const struct _jc_gnu_java_beans_decoder_BooleanHandler$vtype	_jc_gnu_java_beans_decoder_BooleanHandler$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_BooleanHandler$method$_init$7d8397207e40a3b4(_jc_env *, struct _jc_gnu_java_beans_decoder_BooleanHandler$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_BooleanHandler$method$parse$d4a2df662e34a121(_jc_env *, struct _jc_gnu_java_beans_decoder_BooleanHandler$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_BooleanHandler$method_info$parse$d4a2df662e34a121;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_BooleanHandler$vmethods {
	struct _jc_java_lang_Object$object	*(*parse$d4a2df662e34a121)(_jc_env *, struct _jc_gnu_java_beans_decoder_BooleanHandler$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_BooleanHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractElementHandler$vmethods	gnu_java_beans_decoder_AbstractElementHandler;
	_jc_gnu_java_beans_decoder_SimpleHandler$vmethods	gnu_java_beans_decoder_SimpleHandler;
	_jc_gnu_java_beans_decoder_BooleanHandler$vmethods	gnu_java_beans_decoder_BooleanHandler;
};

// Vtype
struct _jc_gnu_java_beans_decoder_BooleanHandler$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_BooleanHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_BooleanHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_BooleanHandler$refs {
    _jc_gnu_java_beans_decoder_BooleanHandler$sub_refs	gnu_java_beans_decoder_BooleanHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_refs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_refs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_BooleanHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_BooleanHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_nonrefs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_nonrefs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_BooleanHandler$sub_nonrefs	gnu_java_beans_decoder_BooleanHandler;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_BooleanHandler$object {
	_jc_gnu_java_beans_decoder_BooleanHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_BooleanHandler$vtype	*vtype;
	_jc_gnu_java_beans_decoder_BooleanHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_BooleanHandler$vtype _jc_gnu_java_beans_decoder_BooleanHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_BooleanHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_BooleanHandler$class_object;

#endif	/* _JC_gnu_java_beans_decoder_BooleanHandler_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/BooleanHandler.h <==
// class gnu.java.beans.decoder.BooleanHandler

// class file dependencies
// @dep_class 670cc122e6cfc20a gnu_java_beans_decoder_AbstractElementHandler
// @dep_class 825486895891e6aa gnu_java_beans_decoder_BooleanHandler
// @dep_class b0ac10a3c7037665 gnu_java_beans_decoder_SimpleHandler
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_SimpleHandler

#include "gnu/java/beans/decoder/SimpleHandler.h"

#ifndef _JC_gnu_java_beans_decoder_BooleanHandler_H_
#define _JC_gnu_java_beans_decoder_BooleanHandler_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_BooleanHandler$sub_refs	_jc_gnu_java_beans_decoder_BooleanHandler$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_BooleanHandler$sub_nonrefs	_jc_gnu_java_beans_decoder_BooleanHandler$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_BooleanHandler$refs	_jc_gnu_java_beans_decoder_BooleanHandler$refs;
typedef struct _jc_gnu_java_beans_decoder_BooleanHandler$nonrefs	_jc_gnu_java_beans_decoder_BooleanHandler$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_BooleanHandler$object	_jc_gnu_java_beans_decoder_BooleanHandler$object;

typedef const struct _jc_gnu_java_beans_decoder_BooleanHandler$vmethods	_jc_gnu_java_beans_decoder_BooleanHandler$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_BooleanHandler$vtable	_jc_gnu_java_beans_decoder_BooleanHandler$vtable;
typedef const struct _jc_gnu_java_beans_decoder_BooleanHandler$vtype	_jc_gnu_java_beans_decoder_BooleanHandler$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_BooleanHandler$method$_init$7d8397207e40a3b4(_jc_env *, struct _jc_gnu_java_beans_decoder_BooleanHandler$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_BooleanHandler$method$parse$d4a2df662e34a121(_jc_env *, struct _jc_gnu_java_beans_decoder_BooleanHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_BooleanHandler$method_info$parse$d4a2df662e34a121;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_BooleanHandler$vmethods {
	struct _jc_java_lang_Object$object	*(*parse$d4a2df662e34a121)(_jc_env *, struct _jc_gnu_java_beans_decoder_BooleanHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_BooleanHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractElementHandler$vmethods	gnu_java_beans_decoder_AbstractElementHandler;
	_jc_gnu_java_beans_decoder_SimpleHandler$vmethods	gnu_java_beans_decoder_SimpleHandler;
	_jc_gnu_java_beans_decoder_BooleanHandler$vmethods	gnu_java_beans_decoder_BooleanHandler;
};

// Vtype
struct _jc_gnu_java_beans_decoder_BooleanHandler$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_BooleanHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_BooleanHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_BooleanHandler$refs {
    _jc_gnu_java_beans_decoder_BooleanHandler$sub_refs	gnu_java_beans_decoder_BooleanHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_refs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_refs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_BooleanHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_BooleanHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_nonrefs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_nonrefs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_BooleanHandler$sub_nonrefs	gnu_java_beans_decoder_BooleanHandler;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_BooleanHandler$object {
	_jc_gnu_java_beans_decoder_BooleanHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_BooleanHandler$vtype	*vtype;
	_jc_gnu_java_beans_decoder_BooleanHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_BooleanHandler$vtype _jc_gnu_java_beans_decoder_BooleanHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_BooleanHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_BooleanHandler$class_object;

#endif	/* _JC_gnu_java_beans_decoder_BooleanHandler_H_ */
